@@ -1,18 +1,23 @@
 """
-    flask_marshmallow
-    ~~~~~~~~~~~~~~~~~
+flask_marshmallow
+~~~~~~~~~~~~~~~~~
 
-    Integrates the marshmallow serialization/deserialization library
-    with your Flask application.
+Integrates the marshmallow serialization/deserialization library
+with your Flask application.
 """
+
+import typing
 import warnings
-from packaging.version import Version
 
-from marshmallow import fields as base_fields, exceptions, pprint
+from marshmallow import exceptions, pprint
+from marshmallow import fields as base_fields
 
 from . import fields
 from .schema import Schema
 
+if typing.TYPE_CHECKING:
+    from flask import Flask
+
 has_sqla = False
 try:
     import flask_sqlalchemy  # noqa: F401
@@ -24,14 +29,20 @@ else:
     except ImportError:
         warnings.warn(
             "Flask-SQLAlchemy integration requires "
-            "marshmallow-sqlalchemy to be installed."
+            "marshmallow-sqlalchemy to be installed.",
+            stacklevel=2,
         )
     else:
         has_sqla = True
 
-__version__ = "0.15.0"
-__version_info__ = Version(__version__).release
-__all__ = ["EXTENSION_NAME", "Marshmallow", "Schema", "fields", "exceptions", "pprint"]
+__all__ = [
+    "EXTENSION_NAME",
+    "Marshmallow",
+    "Schema",
+    "fields",
+    "exceptions",
+    "pprint",
+]
 
 EXTENSION_NAME = "flask-marshmallow"
 
@@ -65,24 +76,27 @@ class Marshmallow:
 
         class BookSchema(ma.Schema):
             class Meta:
-                fields = ('id', 'title', 'author', 'links')
+                fields = ("id", "title", "author", "links")
 
             author = ma.Nested(AuthorSchema)
 
-            links = ma.Hyperlinks({
-                'self': ma.URLFor('book_detail', values=dict(id='<id>')),
-                'collection': ma.URLFor('book_list')
-            })
+            links = ma.Hyperlinks(
+                {
+                    "self": ma.URLFor("book_detail", values=dict(id="<id>")),
+                    "collection": ma.URLFor("book_list"),
+                }
+            )
 
 
-    In order to integrate with Flask-SQLAlchemy, this extension must be initialized *after*
-    `flask_sqlalchemy.SQLAlchemy`. ::
+    In order to integrate with Flask-SQLAlchemy, this extension must be initialized
+    *after* `flask_sqlalchemy.SQLAlchemy`. ::
 
             db = SQLAlchemy(app)
             ma = Marshmallow(app)
 
-    This gives you access to `ma.SQLAlchemySchema` and `ma.SQLAlchemyAutoSchema`, which generate
-    marshmallow `~marshmallow.Schema` classes based on the passed in model or table. ::
+    This gives you access to `ma.SQLAlchemySchema` and `ma.SQLAlchemyAutoSchema`, which
+    generate marshmallow `~marshmallow.Schema` classes
+    based on the passed in model or table. ::
 
         class AuthorSchema(ma.SQLAlchemyAutoSchema):
             class Meta:
@@ -91,7 +105,7 @@ class Marshmallow:
     :param Flask app: The Flask application object.
     """
 
-    def __init__(self, app=None):
+    def __init__(self, app: typing.Optional["Flask"] = None):
         self.Schema = Schema
         if has_sqla:
             self.SQLAlchemySchema = sqla.SQLAlchemySchema
@@ -102,7 +116,7 @@ class Marshmallow:
         if app is not None:
             self.init_app(app)
 
-    def init_app(self, app):
+    def init_app(self, app: "Flask"):
         """Initializes the application with the extension.
 
         :param Flask app: The Flask application object.
@@ -112,8 +126,6 @@ class Marshmallow:
         # If using Flask-SQLAlchemy, attach db.session to SQLAlchemySchema
         if has_sqla and "sqlalchemy" in app.extensions:
             db = app.extensions["sqlalchemy"]
-            if self.SQLAlchemySchema:
-                self.SQLAlchemySchema.OPTIONS_CLASS.session = db.session
-            if self.SQLAlchemyAutoSchema:
-                self.SQLAlchemyAutoSchema.OPTIONS_CLASS.session = db.session
+            self.SQLAlchemySchema.OPTIONS_CLASS.session = db.session
+            self.SQLAlchemyAutoSchema.OPTIONS_CLASS.session = db.session
         app.extensions[EXTENSION_NAME] = self
