@@ -1,14 +1,16 @@
 """
-    flask_marshmallow.fields
-    ~~~~~~~~~~~~~~~~~~~~~~~~
+flask_marshmallow.fields
+~~~~~~~~~~~~~~~~~~~~~~~~
 
-    Custom, Flask-specific fields.
+Custom, Flask-specific fields.
 
-    See the `marshmallow.fields` module for the list of all fields available from the
-    marshmallow library.
+See the `marshmallow.fields` module for the list of all fields available from the
+marshmallow library.
 """
+
 import re
 import typing
+from collections.abc import Sequence
 
 from flask import current_app, url_for
 from marshmallow import fields, missing
@@ -75,10 +77,10 @@ class URLFor(fields.Field):
 
     Usage: ::
 
-        url = URLFor('author_get', values=dict(id='<id>'))
+        url = URLFor("author_get", values=dict(id="<id>"))
         https_url = URLFor(
-            'author_get',
-            values=dict(id='<id>', _scheme='https', _external=True),
+            "author_get",
+            values=dict(id="<id>", _scheme="https", _external=True),
         )
 
     :param str endpoint: Flask endpoint name.
@@ -175,19 +177,23 @@ class Hyperlinks(fields.Field):
 
     Example: ::
 
-        _links = Hyperlinks({
-            'self': URLFor('author', values=dict(id='<id>')),
-            'collection': URLFor('author_list'),
-        })
+        _links = Hyperlinks(
+            {
+                "self": URLFor("author", values=dict(id="<id>")),
+                "collection": URLFor("author_list"),
+            }
+        )
 
     `URLFor` objects can be nested within the dictionary. ::
 
-        _links = Hyperlinks({
-            'self': {
-                'href': URLFor('book', values=dict(id='<id>')),
-                'title': 'book detail'
+        _links = Hyperlinks(
+            {
+                "self": {
+                    "href": URLFor("book", values=dict(id="<id>")),
+                    "title": "book detail",
+                }
             }
-        })
+        )
 
     :param dict schema: A dict that maps names to
         :class:`~flask_marshmallow.fields.URLFor` fields.
@@ -220,6 +226,17 @@ class File(fields.Field):
 
     default_error_messages = {"invalid": "Not a valid file."}
 
+    def deserialize(
+        self,
+        value: typing.Any,
+        attr: typing.Optional[str] = None,
+        data: typing.Optional[typing.Mapping[str, typing.Any]] = None,
+        **kwargs,
+    ):
+        if isinstance(value, Sequence) and len(value) == 0:
+            value = missing
+        return super().deserialize(value, attr, data, **kwargs)
+
     def _deserialize(self, value, attr, data, **kwargs):
         from werkzeug.datastructures import FileStorage
 
@@ -236,11 +253,12 @@ class Config(fields.Field):
         from flask import Flask
 
         app = Flask(__name__)
-        app.config['API_TITLE'] = 'Pet API'
+        app.config["API_TITLE"] = "Pet API"
+
 
         class FooSchema(Schema):
             user = String()
-            title = Config('API_TITLE')
+            title = Config("API_TITLE")
 
     This field should only be used in an output schema. A ``ValueError`` will
     be raised if the config key is not found in the app config.
